@@ -197,7 +197,7 @@ class ErrorHandler(utils.Cog):
         instead. If it fails that too, it just stays silent.
         """
 
-        ephemeral = ctx.IS_INTERACTION and self.bot.config.get("ephemeral_error_messages", True)
+        ephemeral = ctx.is_interaction and self.bot.config.get("ephemeral_error_messages", True)
         try:
             return await ctx.send(
                 text,
