@@ -14,7 +14,7 @@ class MiscCommands(utils.Cog):
         Gives the invite to the support server.
         """
 
-        await ctx.send(f"<{self.bot.config['command_data']['guild_invite']}>", embeddify=False)
+        await ctx.send(f"{self.bot.config['command_data']['guild_invite']}", embeddify=False)
 
     @utils.command(aliases=['patreon'], add_slash_command=False)
     @utils.checks.is_config_set('command_data', 'donate_link')
@@ -24,7 +24,7 @@ class MiscCommands(utils.Cog):
         Gives you the bot's creator's donate link.
         """
 
-        await ctx.send(f"<{self.bot.config['command_data']['donate_link']}>", embeddify=False)
+        await ctx.send(f"{self.bot.config['command_data']['donate_link']}", embeddify=False)
 
     @utils.command(add_slash_command=False)
     @commands.bot_has_permissions(send_messages=True)
@@ -34,7 +34,7 @@ class MiscCommands(utils.Cog):
         Gives you a link to the bot's website.
         """
 
-        await ctx.send(f"<{self.bot.config['command_data']['website_link']}>", embeddify=False)
+        await ctx.send(f"{self.bot.config['command_data']['website_link']}", embeddify=False)
 
     @utils.command(aliases=['information'], add_slash_command=False)
     @commands.bot_has_permissions(send_messages=True)
