@@ -6,7 +6,34 @@ import asyncpg
 
 class DatabaseConnection(object):
     """
-    A helper class to wrap around an :class:`asyncpg.Connection` object.
+    A helper class to wrap around an :class:`asyncpg.Connection` object. This class is
+    written so you don't need to interface with asyncpg directly (though you can if you
+    want by using the :attr:`conn` attribute), and can be easily accessed via the :attr:`Bot.database`
+    attribute.
+
+    Examples:
+
+        ::
+
+            # The database can be used via context
+            async with bot.database() as db:
+                values = await db("SELECT user_id FROM user_settings WHERE enabled=$1", True)
+            for row in values:
+                print(row['user_id'])
+
+            # Or you can get a connection object that you can pass around
+            db = await bot.database.get_connection()
+            await db("DELETE FROM user_settings")
+            await db.disconnect()
+
+            # And transactions are also available
+            async with bot.database() as db:
+                await db.start_transaction()
+                await db("DELETE FROM guild_settings")
+                await db.commit_transaction()
+
+    Attributes:
+        conn (asyncpg.Connection): The asyncpg connection object that we use internally.
     """
 
     config: dict = None
@@ -14,19 +41,21 @@ class DatabaseConnection(object):
     logger: logging.Logger = None
     __slots__ = ('conn', 'transaction', 'is_active',)
 
-    def __init__(self, connection:asyncpg.Connection=None, transaction:asyncpg.transaction.Transaction=None):
+    def __init__(self, connection: asyncpg.Connection = None, transaction: asyncpg.transaction.Transaction = None):
         """:meta private:"""
+
         self.conn = connection
         self.transaction = transaction
         self.is_active = False
 
     @classmethod
-    async def create_pool(cls, config:dict) -> None:
+    async def create_pool(cls, config: dict) -> None:
         """
         Creates the database pool and plonks it in :attr:`DatabaseConnection.pool`.
 
         Args:
-            config (dict): The configuration for the dictionary, passed directly to :func:`asyncpg.create_pool` as kwargs.
+            config (dict): The configuration for the dictionary, passed directly to
+                :func:`asyncpg.create_pool` as kwargs.
         """
 
         cls.config = config.copy()
@@ -45,7 +74,10 @@ class DatabaseConnection(object):
             DatabaseConnection: The connection that was aquired from the pool.
         """
 
-        conn = await cls.pool.acquire()
+        try:
+            conn = await cls.pool.acquire()
+        except AttributeError:
+            raise Exception("Could not open a database connection as the database is disabled in your config.")
         v = cls(conn)
         v.is_active = True
         return v
@@ -87,7 +119,7 @@ class DatabaseConnection(object):
     async def __aexit__(self, exc_type, exc, tb):
         await self.disconnect()
 
-    async def __call__(self, sql:str, *args) -> typing.Union[typing.List[dict], None]:
+    async def __call__(self, sql: str, *args) -> typing.List[dict]:
         """
         Runs a line of SQL and returns a list, if things are expected back, or None, if nothing of interest is happening.
 
@@ -123,7 +155,7 @@ class DatabaseConnection(object):
             return []
         return None
 
-    async def execute_many(self, sql:str, *args) -> None:
+    async def execute_many(self, sql: str, *args) -> None:
         """
         Runs an executemany query.
 
@@ -136,7 +168,9 @@ class DatabaseConnection(object):
         await self.conn.executemany(sql, args)
         return None
 
-    async def copy_records_to_table(self, table_name:str, *, records:typing.List[typing.Any], columns:typing.Tuple[str]=None, timeout:float=None) -> str:
+    async def copy_records_to_table(
+            self, table_name: str, *, records: typing.List[typing.Any],
+            columns: typing.Tuple[str] = None, timeout: float = None) -> str:
         """
         Copies a series of records to a given table.
 
@@ -147,7 +181,7 @@ class DatabaseConnection(object):
             timeout (float, optional): The timeout for the copy command.
 
         Returns:
-            str: The COPY status string
+            str: The COPY status string.
         """
 
         return await self.conn.copy_records_to_table(
